<?php $TRANSLATIONS = array(
"The php-json module is needed by the many applications for inter communications" => "O módulo php-json precísase para a intercomunicación de varios aplicativos",
"The php-curl module is needed to fetch the page title when adding a bookmark" => "O módulo php-curl precísase para a busca de títulos de páxina cando se engaden marcadores",
"The php-gd module is needed to create thumbnails of your images" => "O módulo php-gd precísase para crear as miniaturas das súas imaxes",
"The php-ldap module is needed connect to your ldap server" => "O módulo php-ldap precísase para conectar co seu servidor ldap",
"The php-zip module is needed download multiple files at once" => "O módulo php-zip precísase para descargar varios ficheiros ao mesmo tempo",
"The php-mb_multibyte module is needed to manage correctly the encoding." => "O módulo php-mb_multibyte precísase para xestionar correctamente a codificación.",
"The php-ctype module is needed validate data." => "O módulo php-ctype precísase para validar datos.",
"The php-xml module is needed to share files with webdav." => "O módulo php-xml precísase para compartir ficheiros con webdav.",
"The allow_url_fopen directive of your php.ini should be set to 1 to retrieve knowledge base from OCS servers" => "A directiva allow_url_fopen do seu php.ini debe estabelecerse a 1 para obter coñecemento básico desde servidores OCS",
"The php-pdo module is needed to store owncloud data into a database." => "O módulo php-pdo precísase para gardar datos de owncloud na base de datos.",
"The iconv module is needed to convert data into the correct charset." => "O módulo iconv precisase para converter datos no conxunto de caracteres correcto.",
"Dependencies status" => "Estado das dependencias",
"Used by :" => "Empregado por:"
);
